package cn.wise.sc.cement.business.controller;


import cn.hutool.core.util.StrUtil;
import cn.wise.sc.cement.business.entity.Method;
import cn.wise.sc.cement.business.entity.SysGroup;
import cn.wise.sc.cement.business.entity.Team;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.query.TeamQuery;
import cn.wise.sc.cement.business.service.ISysGroupService;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
 *  前端控制器
 * </p>
 *
 * @author ztw
 * @since 2020-08-18
 */
@Api(tags = "组别管理")
@RestController
@RequestMapping("/business/sys-group")
public class SysGroupController {
	private static final Logger log = LoggerFactory.getLogger("SysGroupController");

	@Autowired
	private ISysGroupService groupService;

	@ApiOperation(value = "组别分页列表")
	@GetMapping("/getPage")
	public BaseResponse getPage(PageQuery pageQuery) {
		try {
			return groupService.getPage(pageQuery);
		} catch (Exception e) {
			log.debug("组别分页列表{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}


	@ApiOperation(value = "组别详情")
	@GetMapping("{id}")
	public BaseResponse getById(@PathVariable Integer id){
		try {
			SysGroup e = groupService.getById(id);
			if(e == null){
				return BaseResponse.errorMsg("信息错误!");
			}
			return BaseResponse.okData(e);
		}catch (Exception e){
			log.debug("组别详情{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "获取组别信息")
	@GetMapping("/getList")
	public BaseResponse getList() {
		try {
			return groupService.getList();
		} catch (Exception e) {
			log.debug("获取组别信息{}", e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "新增")
	@PostMapping("/create")
	public BaseResponse create(@RequestBody SysGroup query){
		try {
			return groupService.create(query);
		}catch (Exception e){
			log.debug("新增{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}

	@ApiOperation(value = "更新")
	@PostMapping("/update")
	public BaseResponse update(@RequestBody SysGroup query){
		try {
			return groupService.update(query);
		}catch (Exception e){
			log.debug("更新{}",e);
		}
		return BaseResponse.errorMsg("失败!");
	}


























}

